r28927 - in /trunk/libclass-c3-adopt-next-perl: Changes MANIFEST META.yml README debian/changelog lib/Class/C3/Adopt/NEXT.pm xt/release/

eloy at users.alioth.debian.org eloy at users.alioth.debian.org
Mon Dec 29 09:24:43 UTC 2008


Author: eloy
Date: Mon Dec 29 09:24:40 2008
New Revision: 28927

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=28927
Log:
new upstream version

Added:
    trunk/libclass-c3-adopt-next-perl/xt/release/
      - copied from r28926, branches/upstream/libclass-c3-adopt-next-perl/current/xt/release/
Modified:
    trunk/libclass-c3-adopt-next-perl/Changes
    trunk/libclass-c3-adopt-next-perl/MANIFEST
    trunk/libclass-c3-adopt-next-perl/META.yml
    trunk/libclass-c3-adopt-next-perl/README
    trunk/libclass-c3-adopt-next-perl/debian/changelog
    trunk/libclass-c3-adopt-next-perl/lib/Class/C3/Adopt/NEXT.pm

Modified: trunk/libclass-c3-adopt-next-perl/Changes
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/Changes?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/Changes (original)
+++ trunk/libclass-c3-adopt-next-perl/Changes Mon Dec 29 09:24:40 2008
@@ -1,3 +1,6 @@
+0.06  Thu, 25 Dec 2008 00:15:14 +0100
+  * Update documentation.
+
 0.05  Sat, 20 Dec 2008 16:04:48 +0100
   * Upgrade Module::Install::ExtraTests to 0.006. This makes things work on
     Win32 again (closes RT#41817).

Modified: trunk/libclass-c3-adopt-next-perl/MANIFEST
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/MANIFEST?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/MANIFEST (original)
+++ trunk/libclass-c3-adopt-next-perl/MANIFEST Mon Dec 29 09:24:40 2008
@@ -22,3 +22,4 @@
 t/nowarn.t
 xt/author/pod.t
 xt/author/pod_spelling.t
+xt/release/meta_yml.t

Modified: trunk/libclass-c3-adopt-next-perl/META.yml
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/META.yml?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/META.yml (original)
+++ trunk/libclass-c3-adopt-next-perl/META.yml Mon Dec 29 09:24:40 2008
@@ -1,5 +1,5 @@
 ---
-abstract: ~
+abstract: 'make NEXT suck less'
 author:
   - 'Florian Ragwitz C<rafl at debian.org>'
 build_requires:
@@ -20,4 +20,4 @@
   NEXT: 0
 resources:
   license: http://dev.perl.org/licenses/
-version: 0.05
+version: 0.06

Modified: trunk/libclass-c3-adopt-next-perl/README
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/README?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/README (original)
+++ trunk/libclass-c3-adopt-next-perl/README Mon Dec 29 09:24:40 2008
@@ -1,11 +1,17 @@
 NAME
-    Class::C3::Adopt::NEXT
+    Class::C3::Adopt::NEXT - make NEXT suck less
 
 SYNOPSIS
         package MyApp::Plugin::FooBar;
         #use NEXT;
         use Class::C3::Adopt::NEXT;
-        # or 'use Class::C3::Adopt::NEXT' -no_warn to suppress warning
+        # or 'use Class::C3::Adopt::NEXT -no_warn;' to suppress warnings
+
+        # Or use warnings::register
+        # no warnings 'Class::C3::Adopt::NEXT';
+
+        # Or suppress warnings in a set of modules from one place
+        # no Class::C3::Adopt::NEXT qw/ Module1 Module2 Module3 /;
 
         sub a_method {
             my ($self) = @_;
@@ -37,7 +43,13 @@
 WARNINGS
     This module will warn once for each package using NEXT. It uses
     warnings::register, and so can be disabled like by adding "no warnings
-    'Class::C3::Adopt::NEXT';" to each package which generates a warning.
+    'Class::C3::Adopt::NEXT';" to each package which generates a warning, or
+    adding "use Class::C3::Adopt::NEXT -no_warn;", or disable multiple
+    modules at once by saying:
+
+        no Class::C3::Adopt::Next qw/ Module1 Module2 Module3 /;
+
+    somewhere before the warnings are first triggered.
 
 MIGRATING
     There are two main reasons for using NEXT:

Modified: trunk/libclass-c3-adopt-next-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/debian/changelog?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/debian/changelog (original)
+++ trunk/libclass-c3-adopt-next-perl/debian/changelog Mon Dec 29 09:24:40 2008
@@ -1,3 +1,9 @@
+libclass-c3-adopt-next-perl (0.06-1) unstable; urgency=low
+
+  * New upstream release
+
+ -- Krzysztof Krzyżaniak (eloy) <eloy at debian.org>  Mon, 29 Dec 2008 10:18:46 +0100
+
 libclass-c3-adopt-next-perl (0.05-1) unstable; urgency=low
 
   * New upstream release

Modified: trunk/libclass-c3-adopt-next-perl/lib/Class/C3/Adopt/NEXT.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libclass-c3-adopt-next-perl/lib/Class/C3/Adopt/NEXT.pm?rev=28927&op=diff
==============================================================================
--- trunk/libclass-c3-adopt-next-perl/lib/Class/C3/Adopt/NEXT.pm (original)
+++ trunk/libclass-c3-adopt-next-perl/lib/Class/C3/Adopt/NEXT.pm Mon Dec 29 09:24:40 2008
@@ -7,7 +7,7 @@
 use MRO::Compat;
 use warnings::register;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 {
     my %c3_mro_ok;
@@ -78,14 +78,20 @@
 
 =head1 NAME
 
-Class::C3::Adopt::NEXT
+Class::C3::Adopt::NEXT - make NEXT suck less
 
 =head1 SYNOPSIS
 
     package MyApp::Plugin::FooBar;
     #use NEXT;
     use Class::C3::Adopt::NEXT;
-    # or 'use Class::C3::Adopt::NEXT' -no_warn to suppress warning
+    # or 'use Class::C3::Adopt::NEXT -no_warn;' to suppress warnings
+
+    # Or use warnings::register
+    # no warnings 'Class::C3::Adopt::NEXT';
+
+    # Or suppress warnings in a set of modules from one place
+    # no Class::C3::Adopt::NEXT qw/ Module1 Module2 Module3 /;
 
     sub a_method {
         my ($self) = @_;
@@ -118,7 +124,12 @@
 This module will warn once for each package using NEXT. It uses
 L<warnings::register>, and so can be disabled like by adding
 C<no warnings 'Class::C3::Adopt::NEXT';> to each package which generates a
-warning.
+warning, or adding C<use Class::C3::Adopt::NEXT -no_warn;>, or disable
+multiple modules at once by saying:
+
+    no Class::C3::Adopt::Next qw/ Module1 Module2 Module3 /;
+
+somewhere before the warnings are first triggered.
 
 =head1 MIGRATING
 




More information about the Pkg-perl-cvs-commits mailing list